EXPORTS
	?NewL@CSsmMapperUtility@@SAPAV1@XZ @ 1 NONAME ; class CSsmMapperUtility * CSsmMapperUtility::NewL(void)
	?GetCommandListPath@CSsmMapperUtility@@UAEXAAVTDes16@@@Z @ 2 NONAME ; void CSsmMapperUtility::GetCommandListPath(class TDes16 &)
	?CrValue@CSsmMapperUtility@@QAEHABVTUid@@KAAVTDes16@@@Z @ 3 NONAME ; int CSsmMapperUtility::CrValue(class TUid const &, unsigned long, class TDes16 &)
	?FeatureStatus@SsmMapperUtility@@SAHABVTUid@@@Z @ 4 NONAME ; int SsmMapperUtility::FeatureStatus(class TUid const &)
	??1CSsmMapperUtility@@UAE@XZ @ 5 NONAME ; CSsmMapperUtility::~CSsmMapperUtility(void)
	?GetCurrentState@SsmMapperUtility@@SAHAAVTSsmState@@@Z @ 6 NONAME ; int SsmMapperUtility::GetCurrentState(class TSsmState &)
	?CrUid@SsmMapperUtility@@SA?AVTUid@@ABV2@@Z @ 7 NONAME ; class TUid SsmMapperUtility::CrUid(class TUid const &)
	?CrValue@SsmMapperUtility@@SAHABVTUid@@KAAH@Z @ 8 NONAME ; int SsmMapperUtility::CrValue(class TUid const &, unsigned long, int &)
	?CrValue@SsmMapperUtility@@SAHABVTUid@@KAAVTDes16@@@Z @ 9 NONAME ; int SsmMapperUtility::CrValue(class TUid const &, unsigned long, class TDes16 &)
	?CheckCaps@SsmMapperUtility@@SAHABVRMessagePtr2@@@Z @ 10 NONAME ; int SsmMapperUtility::CheckCaps(class RMessagePtr2 const &)
	?CheckCaps@CSsmMapperUtility@@UAEHABVRMessagePtr2@@@Z @ 11 NONAME ; int CSsmMapperUtility::CheckCaps(class RMessagePtr2 const &)
	?CrValue@CSsmMapperUtility@@QAEHABVTUid@@KAAH@Z @ 12 NONAME ; int CSsmMapperUtility::CrValue(class TUid const &, unsigned long, int &)
	?FeatureStatus@CSsmMapperUtility@@QAEHABVTUid@@@Z @ 13 NONAME ; int CSsmMapperUtility::FeatureStatus(class TUid const &)
	??0CSsmMapperUtility@@QAE@XZ @ 14 NONAME ; CSsmMapperUtility::CSsmMapperUtility(void)
	?PsUid@SsmMapperUtility@@SA?AVTUid@@ABV2@@Z @ 15 NONAME ; class TUid SsmMapperUtility::PsUid(class TUid const &)
	?GetCommandListPath@SsmMapperUtility@@SAXAAVTDes16@@@Z @ 16 NONAME ; void SsmMapperUtility::GetCommandListPath(class TDes16 &)
	?FeatureUid@SsmMapperUtility@@SA?AVTUid@@ABV2@@Z @ 17 NONAME ; class TUid SsmMapperUtility::FeatureUid(class TUid const &)

